MethodChannelKalapaBehaviorScoreFlutter class

An implementation of KalapaBehaviorScoreFlutterPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(String appToken, String datasetId, List<IKalapaModule> modules, Map<String, bool> extras) Future<String?>
override
collect() Future<KLPBehaviorScoreResult?>
override
getPlatformVersion() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendBehaviorEvent(Map<String, dynamic> event) → void
override
sendBehaviorEventsContinuous(List<Map<String, dynamic>> events) Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited