KalapaBehaviorScoreFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • KalapaBehaviorScoreFlutterPlatform
Implementers

Constructors

KalapaBehaviorScoreFlutterPlatform()
Constructs a KalapaBehaviorScoreFlutterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(String appToken, String datasetId, List<IKalapaModule> modules, Map<String, bool> extras) Future<String?>
collect() Future<KLPBehaviorScoreResult?>
getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendBehaviorEvent(Map<String, dynamic> event) → void
sendBehaviorEventsContinuous(List<Map<String, dynamic>> events) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance KalapaBehaviorScoreFlutterPlatform
The default instance of KalapaBehaviorScoreFlutterPlatform to use.
getter/setter pair