KLPPosition class
Constructors
- KLPPosition.fromJson(dynamic json)
-
factory
-
KLPPosition.multiple(List<
KLPPointWrapper> ? multiple) -
const
- KLPPosition.single(KLPPointWrapper? single)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMultiple → bool
-
no setter
- isSingle → bool
-
no setter
-
multiple
→ List<
KLPPointWrapper> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- single → KLPPointWrapper?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → dynamic -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited