KalapaBehaviorScoreFlutter class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modules
↔ List<
IKalapaModule> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useDevEnvironment ↔ bool
-
getter/setter pair
Methods
-
addModule(
IKalapaModule module) → KalapaBehaviorScoreFlutter -
build(
String appToken, String datasetId) → Future< String?> - Builds the Kalapa behavior score with the provided parameters.
-
collect(
) → Future< KLPBehaviorScoreResult?> -
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendBehaviorEvent(
Map< String, dynamic> event) → void -
sendBehaviorEventsContinuous(
List< Map< events) → Future<String, dynamic> >bool> -
switchEnvironment(
bool useDevEnvironment) → KalapaBehaviorScoreFlutter -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited